@@ -250,8 +250,8 @@ def test_venv_fails_not_inline(tmp_path, capsys, mocker):
         if os.geteuid() == 0:
             pytest.skip("no way to check permission restriction when running under root")
 
-    def _session_via_cli(args, options=None):
-        session = session_via_cli(args, options)
+    def _session_via_cli(args, options=None, setup_logging=True):
+        session = session_via_cli(args, options, setup_logging)
         assert session.creator.can_be_inline is False
         return session
 
